# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['Service']


class Service(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acknowledgement_timeout: Optional[pulumi.Input[str]] = None,
                 alert_creation: Optional[pulumi.Input[str]] = None,
                 alert_grouping: Optional[pulumi.Input[str]] = None,
                 alert_grouping_timeout: Optional[pulumi.Input[int]] = None,
                 auto_resolve_timeout: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 escalation_policy: Optional[pulumi.Input[str]] = None,
                 incident_urgency_rule: Optional[pulumi.Input[pulumi.InputType['ServiceIncidentUrgencyRuleArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 scheduled_actions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ServiceScheduledActionArgs']]]]] = None,
                 support_hours: Optional[pulumi.Input[pulumi.InputType['ServiceSupportHoursArgs']]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        A [service](https://v2.developer.pagerduty.com/v2/page/api-reference#!/Services/get_services) represents something you monitor (like a web service, email service, or database service). It is a container for related incidents that associates them with escalation policies.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_pagerduty as pagerduty

        example_user = pagerduty.User("exampleUser",
            email="125.greenholt.earline@graham.name",
            teams=[pagerduty_team["example"]["id"]])
        foo = pagerduty.EscalationPolicy("foo",
            num_loops=2,
            rules=[pagerduty.EscalationPolicyRuleArgs(
                escalation_delay_in_minutes=10,
                targets=[pagerduty.EscalationPolicyRuleTargetArgs(
                    id=example_user.id,
                    type="user",
                )],
            )])
        example_service = pagerduty.Service("exampleService",
            acknowledgement_timeout="600",
            alert_creation="create_incidents",
            auto_resolve_timeout="14400",
            escalation_policy=pagerduty_escalation_policy["example"]["id"])
        ```

        ## Import

        Services can be imported using the `id`, e.g.

        ```sh
         $ pulumi import pagerduty:index/service:Service main PLBP09X
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] acknowledgement_timeout: Time in seconds that an incident changes to the Triggered State after being Acknowledged. Disabled if set to the `"null"` string.
        :param pulumi.Input[str] alert_creation: Must be one of two values. PagerDuty receives events from your monitoring systems and can then create incidents in different ways. Value "create_incidents" is default: events will create an incident that cannot be merged. Value "create_alerts_and_incidents" is the alternative: events will create an alert and then add it to a new incident, these incidents can be merged.
        :param pulumi.Input[str] alert_grouping: Defines how alerts on this service will be automatically grouped into incidents. Note that the alert grouping features are available only on certain plans. If not set, each alert will create a separate incident; If value is set to `time`: All alerts within a specified duration will be grouped into the same incident. This duration is set in the `alert_grouping_timeout` setting (described below). Available on Standard, Enterprise, and Event Intelligence plans; If value is set to `intelligent` - Alerts will be intelligently grouped based on a machine learning model that looks at the alert summary, timing, and the history of grouped alerts. Available on Enterprise and Event Intelligence plan.
        :param pulumi.Input[int] alert_grouping_timeout: The duration in minutes within which to automatically group incoming alerts. This setting applies only when `alert_grouping` is set to `time`. To continue grouping alerts until the incident is resolved, set this value to `0`.
        :param pulumi.Input[str] auto_resolve_timeout: Time in seconds that an incident is automatically resolved if left open for that long. Disabled if set to the `"null"` string.
        :param pulumi.Input[str] escalation_policy: The escalation policy used by this service.
        :param pulumi.Input[str] name: The name of the service.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['acknowledgement_timeout'] = acknowledgement_timeout
            __props__['alert_creation'] = alert_creation
            __props__['alert_grouping'] = alert_grouping
            __props__['alert_grouping_timeout'] = alert_grouping_timeout
            __props__['auto_resolve_timeout'] = auto_resolve_timeout
            __props__['description'] = description
            if escalation_policy is None and not opts.urn:
                raise TypeError("Missing required property 'escalation_policy'")
            __props__['escalation_policy'] = escalation_policy
            __props__['incident_urgency_rule'] = incident_urgency_rule
            __props__['name'] = name
            __props__['scheduled_actions'] = scheduled_actions
            __props__['support_hours'] = support_hours
            __props__['created_at'] = None
            __props__['html_url'] = None
            __props__['last_incident_timestamp'] = None
            __props__['status'] = None
        super(Service, __self__).__init__(
            'pagerduty:index/service:Service',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acknowledgement_timeout: Optional[pulumi.Input[str]] = None,
            alert_creation: Optional[pulumi.Input[str]] = None,
            alert_grouping: Optional[pulumi.Input[str]] = None,
            alert_grouping_timeout: Optional[pulumi.Input[int]] = None,
            auto_resolve_timeout: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            escalation_policy: Optional[pulumi.Input[str]] = None,
            html_url: Optional[pulumi.Input[str]] = None,
            incident_urgency_rule: Optional[pulumi.Input[pulumi.InputType['ServiceIncidentUrgencyRuleArgs']]] = None,
            last_incident_timestamp: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            scheduled_actions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ServiceScheduledActionArgs']]]]] = None,
            status: Optional[pulumi.Input[str]] = None,
            support_hours: Optional[pulumi.Input[pulumi.InputType['ServiceSupportHoursArgs']]] = None) -> 'Service':
        """
        Get an existing Service resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] acknowledgement_timeout: Time in seconds that an incident changes to the Triggered State after being Acknowledged. Disabled if set to the `"null"` string.
        :param pulumi.Input[str] alert_creation: Must be one of two values. PagerDuty receives events from your monitoring systems and can then create incidents in different ways. Value "create_incidents" is default: events will create an incident that cannot be merged. Value "create_alerts_and_incidents" is the alternative: events will create an alert and then add it to a new incident, these incidents can be merged.
        :param pulumi.Input[str] alert_grouping: Defines how alerts on this service will be automatically grouped into incidents. Note that the alert grouping features are available only on certain plans. If not set, each alert will create a separate incident; If value is set to `time`: All alerts within a specified duration will be grouped into the same incident. This duration is set in the `alert_grouping_timeout` setting (described below). Available on Standard, Enterprise, and Event Intelligence plans; If value is set to `intelligent` - Alerts will be intelligently grouped based on a machine learning model that looks at the alert summary, timing, and the history of grouped alerts. Available on Enterprise and Event Intelligence plan.
        :param pulumi.Input[int] alert_grouping_timeout: The duration in minutes within which to automatically group incoming alerts. This setting applies only when `alert_grouping` is set to `time`. To continue grouping alerts until the incident is resolved, set this value to `0`.
        :param pulumi.Input[str] auto_resolve_timeout: Time in seconds that an incident is automatically resolved if left open for that long. Disabled if set to the `"null"` string.
        :param pulumi.Input[str] escalation_policy: The escalation policy used by this service.
        :param pulumi.Input[str] name: The name of the service.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["acknowledgement_timeout"] = acknowledgement_timeout
        __props__["alert_creation"] = alert_creation
        __props__["alert_grouping"] = alert_grouping
        __props__["alert_grouping_timeout"] = alert_grouping_timeout
        __props__["auto_resolve_timeout"] = auto_resolve_timeout
        __props__["created_at"] = created_at
        __props__["description"] = description
        __props__["escalation_policy"] = escalation_policy
        __props__["html_url"] = html_url
        __props__["incident_urgency_rule"] = incident_urgency_rule
        __props__["last_incident_timestamp"] = last_incident_timestamp
        __props__["name"] = name
        __props__["scheduled_actions"] = scheduled_actions
        __props__["status"] = status
        __props__["support_hours"] = support_hours
        return Service(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="acknowledgementTimeout")
    def acknowledgement_timeout(self) -> pulumi.Output[Optional[str]]:
        """
        Time in seconds that an incident changes to the Triggered State after being Acknowledged. Disabled if set to the `"null"` string.
        """
        return pulumi.get(self, "acknowledgement_timeout")

    @property
    @pulumi.getter(name="alertCreation")
    def alert_creation(self) -> pulumi.Output[Optional[str]]:
        """
        Must be one of two values. PagerDuty receives events from your monitoring systems and can then create incidents in different ways. Value "create_incidents" is default: events will create an incident that cannot be merged. Value "create_alerts_and_incidents" is the alternative: events will create an alert and then add it to a new incident, these incidents can be merged.
        """
        return pulumi.get(self, "alert_creation")

    @property
    @pulumi.getter(name="alertGrouping")
    def alert_grouping(self) -> pulumi.Output[Optional[str]]:
        """
        Defines how alerts on this service will be automatically grouped into incidents. Note that the alert grouping features are available only on certain plans. If not set, each alert will create a separate incident; If value is set to `time`: All alerts within a specified duration will be grouped into the same incident. This duration is set in the `alert_grouping_timeout` setting (described below). Available on Standard, Enterprise, and Event Intelligence plans; If value is set to `intelligent` - Alerts will be intelligently grouped based on a machine learning model that looks at the alert summary, timing, and the history of grouped alerts. Available on Enterprise and Event Intelligence plan.
        """
        return pulumi.get(self, "alert_grouping")

    @property
    @pulumi.getter(name="alertGroupingTimeout")
    def alert_grouping_timeout(self) -> pulumi.Output[Optional[int]]:
        """
        The duration in minutes within which to automatically group incoming alerts. This setting applies only when `alert_grouping` is set to `time`. To continue grouping alerts until the incident is resolved, set this value to `0`.
        """
        return pulumi.get(self, "alert_grouping_timeout")

    @property
    @pulumi.getter(name="autoResolveTimeout")
    def auto_resolve_timeout(self) -> pulumi.Output[Optional[str]]:
        """
        Time in seconds that an incident is automatically resolved if left open for that long. Disabled if set to the `"null"` string.
        """
        return pulumi.get(self, "auto_resolve_timeout")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="escalationPolicy")
    def escalation_policy(self) -> pulumi.Output[str]:
        """
        The escalation policy used by this service.
        """
        return pulumi.get(self, "escalation_policy")

    @property
    @pulumi.getter(name="htmlUrl")
    def html_url(self) -> pulumi.Output[str]:
        return pulumi.get(self, "html_url")

    @property
    @pulumi.getter(name="incidentUrgencyRule")
    def incident_urgency_rule(self) -> pulumi.Output['outputs.ServiceIncidentUrgencyRule']:
        return pulumi.get(self, "incident_urgency_rule")

    @property
    @pulumi.getter(name="lastIncidentTimestamp")
    def last_incident_timestamp(self) -> pulumi.Output[str]:
        return pulumi.get(self, "last_incident_timestamp")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the service.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="scheduledActions")
    def scheduled_actions(self) -> pulumi.Output[Optional[Sequence['outputs.ServiceScheduledAction']]]:
        return pulumi.get(self, "scheduled_actions")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="supportHours")
    def support_hours(self) -> pulumi.Output[Optional['outputs.ServiceSupportHours']]:
        return pulumi.get(self, "support_hours")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

